"""Interface to remctl.

    This module is an interface to remctl, a client/server
    protocol for running single commands on a remote host
    using Kerberos v% authentication.
"""

# Author: Thomas L. Kula <kula@tproa.net>
# $Id: remctl.py,v 1.2 2008/02/23 20:05:51 kula Exp $

__version__=0.1

import _remctl


# Error classes

class Error(Exception):
    """Base error class for this module."""
    pass

class RemctlArgError(Error):
    """Invalid arguments supplied."""
    def __init__(self, value):
	self.value = value
    def __str__(self):
	return repr(self.value)

class RemctlProtocolError(Error):
    """An error in the remctl protocol happened."""
    def __init__(self, value):
	self.value = value
    def __str__(self):
	return repr(self.value)

# Simple interface

class RemctlSimpleResult:
    """An object holding the results from the simple interface"""
    def __init__(self):
	self.stdout = None
	self.stderr = None
	self.status = None

def remctl( host = None, port = 4373, principal = None, command = [] ):
    """Simple interface to remctl"""

    if host == None:
	raise RemctlArgError, 'No host supplied'

    try:
	myport = int( port )
    except:
	raise RemctlArgError, "port must be a number"

    if (( myport < 0 ) or ( myport > 65535 )):
	raise RemctlArgError, "invalid port number"

    if principal == None:
	principal = 'host/' + host

    if len( command ) < 2: 
	raise RemctlArgError, "must have two or more arguments to command"

    mycommand = []
    for item in command:
	mycommand.append( str( item ))

    # At this point, everything should be sane. Call the low-level
    # interface

    myresult = _remctl.remctl( host, port, principal, mycommand )

    if myresult[ 0 ] != None:
	raise RemctlProtocolError, myresult[ 0 ]

    result = RemctlSimpleResult()

    setattr( result, 'stdout', myresult[ 1 ])
    setattr( result, 'stderr', myresult[ 2 ])
    setattr( result, 'status', myresult[ 3 ])


    return result

